@@ -138,9 +138,22 @@ public interface DataObjectFactory {
 	 * @param id
 	 *            the IRI string that identifies the datatype
 	 * @return a {@link DatatypeIdValue} corresponding to the input
+	 * @deprecated use {@link #getDatatypeIdValueFromJsonId(String)}
 	 */
 	DatatypeIdValue getDatatypeIdValue(String id);
 
+	/**
+	 * Creates a {@link DatatypeIdValue}. The datatype IRI is usually one of the
+	 * constants defined in {@link DatatypeIdValue}, but this is not enforced,
+	 * since there might be extensions that provide additional types. The JSON
+	 * string is its representation in the JSON serialization of properties.
+	 *
+	 * @param jsonId
+	 * 			  the JSON representation of this datatype, which cannot be null
+	 * @return a {@link DatatypeIdValue} corresponding to the input
+	 */
+	DatatypeIdValue getDatatypeIdValueFromJsonId(String jsonId);
+
 	/**
 	 * Creates a {@link TimeValue}.
 	 *
