@@ -374,7 +374,8 @@ public class DumpProcessingController {
 	 * @see DumpProcessingController#processDump(MwDumpFile)
 	 * @see DumpProcessingController#getMostRecentDump(DumpContentType)
 	 */
-	public void processAllRecentRevisionDumps() {
+	public void processAllRecentRevisionDumps() 
+		throws IOException {
 		WmfDumpFileManager wmfDumpFileManager = getWmfDumpFileManager();
 		if (wmfDumpFileManager == null) {
 			return;
@@ -398,7 +399,8 @@ public class DumpProcessingController {
 	 *
 	 * @see DumpProcessingController#processAllRecentRevisionDumps()
 	 */
-	public void processMostRecentMainDump() {
+	public void processMostRecentMainDump() 
+		throws IOException {
 		DumpContentType dumpContentType;
 		if (this.preferCurrent) {
 			dumpContentType = DumpContentType.CURRENT;
@@ -419,7 +421,8 @@ public class DumpProcessingController {
 	 *
 	 * @see DumpProcessingController#processAllRecentRevisionDumps()
 	 */
-	public void processMostRecentJsonDump() {
+	public void processMostRecentJsonDump() 
+		throws IOException {
 		processDump(getMostRecentDump(DumpContentType.JSON));
 	}
 
@@ -434,7 +437,8 @@ public class DumpProcessingController {
 	 * @param dumpFile
 	 *            the dump to process
 	 */
-	public void processDump(MwDumpFile dumpFile) {
+	public void processDump(MwDumpFile dumpFile) 
+			throws IOException {
 		if (dumpFile == null) {
 			return;
 		}
@@ -493,18 +497,21 @@ public class DumpProcessingController {
 	 *            the dump file processor to use
 	 */
 	void processDumpFile(MwDumpFile dumpFile,
-			MwDumpFileProcessor dumpFileProcessor) {
+			MwDumpFileProcessor dumpFileProcessor) 
+					throws IOException, FileAlreadyExistsException {
 		try (InputStream inputStream = dumpFile.getDumpFileStream()) {
 			dumpFileProcessor.processDumpFileContents(inputStream, dumpFile);
 		} catch (FileAlreadyExistsException e) {
-			logger.error("Dump file "
+			String errorMessage = "Dump file "
 					+ dumpFile.toString()
 					+ " could not be processed since file "
 					+ e.getFile()
-					+ " already exists. Try deleting the file or dumpfile directory to attempt a new download.");
+					+ " already exists. Try deleting the file or dumpfile directory to attempt a new download.";
+			throw new FileAlreadyExistsException(dumpFile.toString(), e.getFile(), errorMessage);
 		} catch (IOException e) {
-			logger.error("Dump file " + dumpFile.toString()
-					+ " could not be processed: " + e.toString());
+			String errorMessage = "Dump file " + dumpFile.toString()
+					+ " could not be processed: " + e.toString();
+			throw new IOException(errorMessage);
 		}
 	}
 
