@@ -33,6 +33,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
+import java.util.Properties;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.commons.lang3.tuple.ImmutablePair;
@@ -42,9 +43,12 @@ import org.wikidata.wdtk.wikibaseapi.apierrors.AssertUserFailedException;
 import org.wikidata.wdtk.wikibaseapi.apierrors.MaxlagErrorException;
 import org.wikidata.wdtk.wikibaseapi.apierrors.MediaWikiApiErrorException;
 import org.wikidata.wdtk.wikibaseapi.apierrors.MediaWikiApiErrorHandler;
+import org.wikidata.wdtk.wikibaseapi.apierrors.MediaWikiErrorMessage;
 
 import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
 import com.fasterxml.jackson.annotation.JsonProperty;
+import com.fasterxml.jackson.core.JsonProcessingException;
+import com.fasterxml.jackson.core.type.TypeReference;
 import com.fasterxml.jackson.databind.JsonNode;
 import com.fasterxml.jackson.databind.ObjectMapper;
 
@@ -67,6 +71,9 @@ public abstract class ApiConnection {
 
 	static final Logger logger = LoggerFactory.getLogger(ApiConnection.class);
 
+    private static final String DEFAULT_FALLBACK_USER_AGENT =
+            "Wikidata-Toolkit/unknown (+https://github.com/Wikidata-Toolkit/Wikidata-Toolkit)";
+
 	/**
 	 * URL of the API of wikidata.org.
 	 */
@@ -131,6 +138,11 @@ public abstract class ApiConnection {
 	 */
 	protected int readTimeout = -1;
 
+    /**
+     * A custom user agent for each HTTP request.
+     */
+    protected String customUserAgent = loadDefaultUserAgent();
+
 	/**
 	 * Http client used for making requests.
 	 */
@@ -285,7 +297,17 @@ public abstract class ApiConnection {
 		return readTimeout;
 	}
 
-	/**
+    @JsonProperty("customUserAgent")
+    public String getCustomUserAgent() {
+        return customUserAgent;
+    }
+
+    public void setCustomUserAgent(String customUserAgent) {
+        this.customUserAgent = customUserAgent;
+        this.client = null;
+    }
+
+    /**
 	 * Logs the current user out.
 	 *
 	 * @throws IOException
@@ -482,13 +504,23 @@ public abstract class ApiConnection {
 			JsonNode errorNode = root.path("error");
 			String code = errorNode.path("code").asText("UNKNOWN");
 			String info = errorNode.path("info").asText("No details provided");
+			
+			List<MediaWikiErrorMessage> messages = Collections.emptyList();
+			if (errorNode.has("messages")) {
+			    try {
+                    messages = this.mapper.treeToValue(errorNode.get("messages"), new TypeReference<List<MediaWikiErrorMessage>>() {});
+                } catch (JsonProcessingException | IllegalArgumentException e) {
+                    logger.warn("Could not parse 'messages' field of API error response");
+                }
+			}
+			
 			// Special case for the maxlag error since we also want to return
 			// the lag value in the exception thrown
 			if (errorNode.has("lag") && MediaWikiApiErrorHandler.ERROR_MAXLAG.equals(code)) {
 				double lag = errorNode.path("lag").asDouble();
 				throw new MaxlagErrorException(info, lag);
 			} else {
-				MediaWikiApiErrorHandler.throwMediaWikiApiErrorException(code, info);
+				MediaWikiApiErrorHandler.throwMediaWikiApiErrorException(code, info, messages);
 			}
 		}
 	}
@@ -606,4 +638,17 @@ public abstract class ApiConnection {
 		return builder.toString();
 	}
 
+    private static String loadDefaultUserAgent() {
+        final Properties properties = new Properties();
+        try (InputStream input = Thread.currentThread().getContextClassLoader().getResourceAsStream("wikidata-tk-http.properties")) {
+            if (input != null) {
+                properties.load(input);
+                return properties.getProperty("user.agent", DEFAULT_FALLBACK_USER_AGENT);
+            }
+        } catch (IOException e) {
+            logger.warn(e.getLocalizedMessage(), e);
+        }
+        return DEFAULT_FALLBACK_USER_AGENT;
+    }
+
 }
