@@ -108,6 +108,7 @@ public class BasicApiConnection extends ApiConnection {
 	@Override
 	protected OkHttpClient.Builder getClientBuilder() {
 		return new OkHttpClient.Builder()
+                .addInterceptor(new UserAgentInterceptor(customUserAgent))
 				.cookieJar(new JavaNetCookieJar(cookieManager));
 	}
 
@@ -184,6 +185,8 @@ public class BasicApiConnection extends ApiConnection {
 				loginFunction.login(token, username, password);
 			} catch (NeedLoginTokenException | TokenErrorException e) { // try once more
 				clearToken("login");
+				clearToken("csrf");
+				clearCookies();
 				token = getOrFetchToken("login");
 				loginFunction.login(token, username, password);
 			}
