@@ -52,6 +52,7 @@ import org.wikidata.wdtk.testing.MockStringContentFactory;
 import org.wikidata.wdtk.wikibaseapi.apierrors.AssertUserFailedException;
 import org.wikidata.wdtk.wikibaseapi.apierrors.MaxlagErrorException;
 import org.wikidata.wdtk.wikibaseapi.apierrors.MediaWikiApiErrorException;
+import org.wikidata.wdtk.wikibaseapi.apierrors.MediaWikiErrorMessage;
 
 import com.fasterxml.jackson.databind.JsonNode;
 import com.fasterxml.jackson.databind.ObjectMapper;
@@ -65,7 +66,7 @@ public class BasicApiConnectionTest {
 	private static MockWebServer server;
 	private BasicApiConnection connection;
 
-	private String LOGGED_IN_SERIALIZED_CONNECTION = "{\"baseUrl\":\"" + server.url("/w/api.php") + "\",\"cookies\":[{\"name\":\"GeoIP\",\"value\":\"DE:13:Dresden:51.0500:13.7500:v4\",\"comment\":null,\"commentURL\":null,\"domain\":\"domain comparison should be skipped\",\"maxAge\":-1,\"path\":\"/\",\"portlist\":null,\"secure\":false,\"httpOnly\":false,\"version\":0,\"discard\":false},{\"name\":\"testwikidatawikiSession\",\"value\":\"c18ef92637227283bcda73bcf95cfaf5\",\"comment\":null,\"commentURL\":null,\"domain\":\"domain comparison should be skipped\",\"maxAge\":-1,\"path\":\"/\",\"portlist\":null,\"secure\":true,\"httpOnly\":true,\"version\":0,\"discard\":false}],\"username\":\"username\",\"loggedIn\":true,\"tokens\":{\"login\":\"b5780b6e2f27e20b450921d9461010b4\"},\"connectTimeout\":5000,\"readTimeout\":6000}";
+	private String LOGGED_IN_SERIALIZED_CONNECTION = "{\"baseUrl\":\"" + server.url("/w/api.php") + "\",\"cookies\":[{\"name\":\"GeoIP\",\"value\":\"DE:13:Dresden:51.0500:13.7500:v4\",\"comment\":null,\"commentURL\":null,\"domain\":\"domain comparison should be skipped\",\"maxAge\":-1,\"path\":\"/\",\"portlist\":null,\"secure\":false,\"httpOnly\":false,\"version\":0,\"discard\":false},{\"name\":\"testwikidatawikiSession\",\"value\":\"c18ef92637227283bcda73bcf95cfaf5\",\"comment\":null,\"commentURL\":null,\"domain\":\"domain comparison should be skipped\",\"maxAge\":-1,\"path\":\"/\",\"portlist\":null,\"secure\":true,\"httpOnly\":true,\"version\":0,\"discard\":false}],\"username\":\"username\",\"loggedIn\":true,\"tokens\":{\"login\":\"b5780b6e2f27e20b450921d9461010b4\"},\"connectTimeout\":5000,\"readTimeout\":6000,\"customUserAgent\":\"customAgent\"}";
 
 	Set<String> split(String str, char ch) {
 		Set<String> set = new TreeSet<>();
@@ -204,6 +205,7 @@ public class BasicApiConnectionTest {
 		connection.login("username", "password");
 		connection.setConnectTimeout(5000);
 		connection.setReadTimeout(6000);
+        connection.setCustomUserAgent("customAgent");
 		assertTrue(connection.isLoggedIn());
 		String jsonSerialization = mapper.writeValueAsString(connection);
 		// We skip comparing the cookie domains here, since they depend on
@@ -328,6 +330,22 @@ public class BasicApiConnectionTest {
 			assertEquals(3.45, e.getLag(), 0.001);
 		}
 	}
+	   
+    @Test
+    public void testAbuseFilterError() throws IOException, MediaWikiApiErrorException {
+        JsonNode root;
+        URL path = this.getClass().getResource("/error-spam-filter.json");
+        root = mapper.readTree(path.openStream());
+        try {
+            connection.checkErrors(root);
+        } catch(MediaWikiApiErrorException e) {
+            List<MediaWikiErrorMessage> expectedMessages = Arrays.asList(
+                    new MediaWikiErrorMessage("wikibase-api-failed-save", "The save has failed."),
+                    new MediaWikiErrorMessage("spam-blacklisted-link", "The text you wanted to publish was blocked by the spam filter.")
+            );
+            assertEquals(expectedMessages, e.getDetailedMessages());
+        }
+    }
 
 	@Test
 	public void testClearCookies() throws LoginFailedException, IOException, MediaWikiApiErrorException {
